@@ -87,6 +87,10 @@ func desiredRouterDeployment(ci *operatorv1.IngressController, ingressController
 	deployment.Spec.Selector = controller.IngressControllerDeploymentPodSelector(ci)
 	deployment.Spec.Template.Labels = controller.IngressControllerDeploymentPodSelector(ci).MatchLabels
 
+	// the router should have a very long grace period by default (1h)
+	gracePeriod := int64(60 * 60)
+	deployment.Spec.Template.Spec.TerminationGracePeriodSeconds = &gracePeriod
+
 	volumes := deployment.Spec.Template.Spec.Volumes
 	routerVolumeMounts := deployment.Spec.Template.Spec.Containers[0].VolumeMounts
 
@@ -114,7 +118,7 @@ func desiredRouterDeployment(ci *operatorv1.IngressController, ingressController
 		// use host networking and specify the same port to the same
 		// node.  Thus no affinity policy is required when using
 		// HostNetwork.
-	case operatorv1.PrivateStrategyType, operatorv1.LoadBalancerServiceStrategyType:
+	case operatorv1.PrivateStrategyType, operatorv1.LoadBalancerServiceStrategyType, operatorv1.NodePortServiceStrategyType:
 		// To avoid downtime during a rolling update, we need two
 		// things: a deployment strategy and affinity policy.  First,
 		// the deployment strategy: During a rolling update, we want the
@@ -430,6 +434,19 @@ func desiredRouterDeployment(ci *operatorv1.IngressController, ingressController
 		env = append(env, corev1.EnvVar{Name: "ROUTER_IP_V4_V6_MODE", Value: mode})
 	}
 
+	routeAdmission := operatorv1.RouteAdmissionPolicy{
+		NamespaceOwnership: operatorv1.StrictNamespaceOwnershipCheck,
+	}
+	if admission := ci.Spec.RouteAdmission; admission != nil && len(admission.NamespaceOwnership) > 0 {
+		routeAdmission.NamespaceOwnership = ci.Spec.RouteAdmission.NamespaceOwnership
+	}
+	switch routeAdmission.NamespaceOwnership {
+	case operatorv1.StrictNamespaceOwnershipCheck:
+		env = append(env, corev1.EnvVar{Name: "ROUTER_DISABLE_NAMESPACE_OWNERSHIP_CHECK", Value: "false"})
+	case operatorv1.InterNamespaceAllowedOwnershipCheck:
+		env = append(env, corev1.EnvVar{Name: "ROUTER_DISABLE_NAMESPACE_OWNERSHIP_CHECK", Value: "true"})
+	}
+
 	deployment.Spec.Template.Spec.Volumes = volumes
 	deployment.Spec.Template.Spec.Containers[0].VolumeMounts = routerVolumeMounts
 	deployment.Spec.Template.Spec.Containers[0].Env = append(deployment.Spec.Template.Spec.Containers[0].Env, env...)
